# astromodels

[![Build Status](https://travis-ci.org/threeML/astromodels.svg?branch=master)](https://travis-ci.org/threeML/astromodels)
[![codecov](https://codecov.io/gh/threeML/astromodels/branch/master/graph/badge.svg)](https://codecov.io/gh/threeML/astromodels)
[![Documentation Status](https://readthedocs.org/projects/astromodels/badge/?version=latest)](http://astromodels.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
![GitHub contributors](https://img.shields.io/github/contributors/threeML/astromodels)

![GitHub pull requests](https://img.shields.io/github/issues-pr/threeML/astromodels)
![GitHub issues](https://img.shields.io/github/issues/threeML/astromodels)
## PyPi

[![PyPI version fury.io](https://badge.fury.io/py/astromodels.svg)](https://pypi.python.org/pypi/astromodels/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/astromodels)

## Conda
![Conda](https://img.shields.io/conda/pn/threeml/astromodels)
![Conda](https://img.shields.io/conda/dn/threeml/astromodels)

Spatial and spectral models for astrophysics

Documentation: http://astromodels.readthedocs.org/en/latest/
